==> security-2016.8-sources.jar: org/wildfly/swarm/security/SecurityFraction.java <==
/**
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wildfly.swarm.security;

import java.util.HashMap;

import javax.annotation.PostConstruct;

import org.wildfly.swarm.config.Security;
import org.wildfly.swarm.config.security.Flag;
import org.wildfly.swarm.config.security.SecurityDomain;
import org.wildfly.swarm.config.security.security_domain.ClassicAuthentication;
import org.wildfly.swarm.config.security.security_domain.authentication.LoginModule;
import org.wildfly.swarm.spi.api.Fraction;
import org.wildfly.swarm.spi.api.annotations.MarshalDMR;
import org.wildfly.swarm.spi.api.annotations.WildFlyExtension;

/**
 * @author Bob McWhirter
 */
@WildFlyExtension(module = "org.jboss.as.security")
@MarshalDMR
public class SecurityFraction extends Security<SecurityFraction> implements Fraction<SecurityFraction> {

    public static SecurityFraction defaultSecurityFraction() {
        return new SecurityFraction().applyDefaults();
    }

    @PostConstruct
    public void postConstruct() {
        applyDefaults();
    }

    public SecurityFraction applyDefaults() {
        return securityDomain(new SecurityDomain("other")
                .classicAuthentication(new ClassicAuthentication()
                        .loginModule(new LoginModule("RealmDirect")
                                .code("RealmDirect")
                                .flag(Flag.REQUIRED)
                                .moduleOptions(new HashMap<Object, Object>() {{
                                    put("password-stacking", "useFirstPass");
                                }})

                        )));
    }

}

==> security-2017.1.1-sources.jar: org/wildfly/swarm/security/SecurityFraction.java <==
/**
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wildfly.swarm.security;

import java.util.HashMap;

import javax.annotation.PostConstruct;

import org.wildfly.swarm.config.Security;
import org.wildfly.swarm.config.security.Flag;
import org.wildfly.swarm.config.security.SecurityDomain;
import org.wildfly.swarm.config.security.security_domain.ClassicAuthentication;
import org.wildfly.swarm.config.security.security_domain.ClassicAuthorization;
import org.wildfly.swarm.config.security.security_domain.JaspiAuthentication;
import org.wildfly.swarm.config.security.security_domain.authentication.AuthModule;
import org.wildfly.swarm.config.security.security_domain.authentication.LoginModule;
import org.wildfly.swarm.config.security.security_domain.authentication.LoginModuleStack;
import org.wildfly.swarm.config.security.security_domain.authorization.PolicyModule;
import org.wildfly.swarm.spi.api.Fraction;
import org.wildfly.swarm.spi.api.annotations.MarshalDMR;
import org.wildfly.swarm.spi.api.annotations.WildFlyExtension;

/**
 * @author Bob McWhirter
 */
@WildFlyExtension(module = "org.jboss.as.security")
@MarshalDMR
public class SecurityFraction extends Security<SecurityFraction> implements Fraction<SecurityFraction> {

    public static SecurityFraction defaultSecurityFraction() {
        return new SecurityFraction().applyDefaults();
    }

    @PostConstruct
    public void postConstruct() {
        applyDefaults();
    }

    public SecurityFraction applyDefaults() {
        securityDomain(new SecurityDomain("other")
                .cacheType(SecurityDomain.CacheType.DEFAULT)
                .classicAuthentication(new ClassicAuthentication()
                        .loginModule(new LoginModule("RealmDirect")
                                .code("RealmDirect")
                                .flag(Flag.REQUIRED)
                                .moduleOptions(new HashMap<Object, Object>() {{
                                    put("password-stacking", "useFirstPass");
                                }})

                        )));

        securityDomain(new SecurityDomain("jaspitest")
                .cacheType(SecurityDomain.CacheType.DEFAULT)
                .jaspiAuthentication(new JaspiAuthentication()
                        .loginModuleStack(new LoginModuleStack("dummy")
                                .loginModule(new LoginModule("Dummy")
                                        .code("Dummy")
                                        .flag(Flag.OPTIONAL)
                                )
                        )
                        .authModule(new AuthModule("Dummy")
                                .code("Dummy")
                        )
                )
        );

        return this;
    }

}
